@@ -1,8 +1,11 @@
+import uuid
 from anyio import sleep
 from .functions_projects import get_list_of_all_project_infos, get_recent_project
 from ._backend_calls import _backend_GET
 from .functions import move_parameter_placeholder
+
 import streamlit as st
+import streamlit_mermaid as stmd
 
 def st_project_selector(title: str = None):
 
@@ -175,7 +178,10 @@ def st_load_components(uid_list: list[str] = None) -> dict[str, dict]:
                                 if status_code == 200 and isinstance(component, dict):
                                     st.session_state['db']['components'][component_uid] = component
                                     if component_uid != component.get("uid"):
-                                        st.session_state['db']['components'][component['uid']] = component_uid
+                                        st.session_state['db']['components'][component['uid']] = component
+                                    if "hash" in component:
+                                        hash_uid = f"{component['uid'].rsplit('_', 1)[0]}_{component['hash']}"
+                                        st.session_state['db']['components'][hash_uid] = component
                                 else:
                                     st.error(f"Error loading component {component_uid}: {component}")
                 else:
@@ -192,11 +198,25 @@ def st_load_components(uid_list: list[str] = None) -> dict[str, dict]:
 
 
     for component_uid, component in st.session_state['db']['components'].items():
-        try:
-            st.session_state['db']['components'][component_uid] = move_parameter_placeholder(component)
-        except AttributeError as e:
-            st.error(f"Error processing component {component_uid}: {e}")
-            st.error(component)
-            st.error(type(component))
+        st.session_state['db']['components'][component_uid] = move_parameter_placeholder(component)
+    
+    return st.session_state['db']['components']
 
-    return st.session_state['db']['components']
\ No newline at end of file
+
+def show_mermaid_diagram(mermaid_code: str=None):
+    """
+    Display a Mermaid diagram in Streamlit using streamlit-mermaid.
+    
+    Parameters:
+        mermaid_code (str, optional): Mermaid diagram definition as a string. If not provided, a default simple graph is shown.
+    
+    Streamlit-Mermaid Options Reference:
+        https://github.com/neka-nat/streamlit-mermaid/blob/main/streamlit_mermaid/frontend/src/MermaidViewer.tsx#L12
+    """
+
+    if not mermaid_code:
+        mermaid_code = """
+        graph LR
+            A[Ex] -->|sam| D[(ple)]
+        """
+    stmd.st_mermaid(mermaid_code, show_controls=False, pan=True, zoom=True, key=f"mermaid_{uuid.uuid4()}")
